pub type StrippedPolicyRuleUserEvent = StrippedStateEvent<PossiblyRedactedPolicyRuleUserEventContent>;Available on crate feature
events only.Expand description
An m.policy.rule.user event from an invited room preview.
Aliased Type
struct StrippedPolicyRuleUserEvent {
pub content: PossiblyRedactedPolicyRuleUserEventContent,
pub sender: OwnedUserId,
pub state_key: String,
}Fields
content: PossiblyRedactedPolicyRuleUserEventContentData specific to the event type.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.